@@ -47,6 +47,8 @@ class Context(object):
 
     symlink_java_src = False # If True, will symlink instead of copying during build
 
+    java_build_tool = 'auto'
+
     @property
     def packages_path(self):
         '''Where packages are downloaded before being unpacked'''
@@ -171,8 +173,6 @@ class Context(object):
         if self._build_env_prepared:
             return
 
-        # AND: This needs revamping to carefully check each dependency
-        # in turn
         ok = True
 
         # Work out where the Android SDK is
@@ -184,7 +184,7 @@ class Context(object):
         if sdk_dir is None:  # This seems used more conventionally
             sdk_dir = environ.get('ANDROID_HOME', None)
         if sdk_dir is None:  # Checks in the buildozer SDK dir, useful
-            #                # for debug tests of p4a
+                             # for debug tests of p4a
             possible_dirs = glob.glob(expanduser(join(
                 '~', '.buildozer', 'android', 'platform', 'android-sdk-*')))
             possible_dirs = [d for d in possible_dirs if not
@@ -323,8 +323,9 @@ class Context(object):
                     warning('If the NDK dir result is correct, you don\'t '
                             'need to manually set the NDK ver.')
         if ndk_ver is None:
-            warning('Android NDK version could not be found, exiting.')
-            exit(1)
+            warning('Android NDK version could not be found. This probably'
+                    'won\'t cause any problems, but if necessary you can'
+                    'set it with `--ndk-version=...`.')
         self.ndk_ver = ndk_ver
 
         info('Using {} NDK {}'.format(self.ndk.capitalize(), self.ndk_ver))
@@ -359,7 +360,7 @@ class Context(object):
             ok = False
             warning("Missing requirement: cython is not installed")
 
-        # AND: need to change if supporting multiple archs at once
+        # This would need to be changed if supporting multiarch APKs
         arch = self.archs[0]
         platform_dir = arch.platform_dir
         toolchain_prefix = arch.toolchain_prefix
@@ -496,7 +497,7 @@ class Context(object):
         dir.
         '''
 
-        # AND: This *must* be replaced with something more general in
+        # This needs to be replaced with something more general in
         # order to support multiple python versions and/or multiple
         # archs.
         if self.python_recipe.from_crystax:
@@ -575,7 +576,6 @@ def build_recipes(build_order, python_modules, ctx):
                      .format(recipe.name))
 
         # 4) biglink everything
-        # AND: Should make this optional
         info_main('# Biglinking object files')
         if not ctx.python_recipe or not ctx.python_recipe.from_crystax:
             biglink(ctx, arch)
@@ -666,12 +666,17 @@ def biglink(ctx, arch):
     info('target {}'.format(join(ctx.get_libs_dir(arch.arch),
                                  'libpymodules.so')))
     do_biglink = copylibs_function if ctx.copy_libs else biglink_function
-    do_biglink(
-        join(ctx.get_libs_dir(arch.arch), 'libpymodules.so'),
-        obj_dir.split(' '),
-        extra_link_dirs=[join(ctx.bootstrap.build_dir,
-                              'obj', 'local', arch.arch)],
-        env=env)
+
+    # Move to the directory containing crtstart_so.o and crtend_so.o
+    # This is necessary with newer NDKs? A gcc bug?
+    with current_directory(join(ctx.ndk_platform, 'usr', 'lib')):
+        do_biglink(
+            join(ctx.get_libs_dir(arch.arch), 'libpymodules.so'),
+            obj_dir.split(' '),
+            extra_link_dirs=[join(ctx.bootstrap.build_dir,
+                                  'obj', 'local', arch.arch),
+                             os.path.abspath('.')],
+            env=env)
 
 
 def biglink_function(soname, objs_paths, extra_link_dirs=[], env=None):
