@@ -7,7 +7,7 @@ class SQLAlchemyRecipe(CompiledComponentsPythonRecipe):
     version = '1.0.9'
     url = 'https://pypi.python.org/packages/source/S/SQLAlchemy/SQLAlchemy-{version}.tar.gz'
     
-    depends = [('python2', 'python3'), 'setuptools']
+    depends = [('python2', 'python3crystax'), 'setuptools']
     
     patches = ['zipsafe.patch']
 
